@@ -56,16 +56,13 @@ static void     gsd_automount_manager_init        (GsdAutomountManager      *gsd
 
 G_DEFINE_TYPE (GsdAutomountManager, gsd_automount_manager, G_TYPE_OBJECT)
 
-static gpointer manager_object = NULL;
-
 static GtkDialog *
 show_error_dialog (const char *primary_text,
-		   const char *secondary_text,
-		   GtkWindow *parent)
+		   const char *secondary_text)
 {
 	GtkWidget *dialog;
 
-	dialog = gtk_message_dialog_new (parent,
+	dialog = gtk_message_dialog_new (NULL,
 					 0,
 					 GTK_MESSAGE_ERROR,
 					 GTK_BUTTONS_OK,
@@ -154,8 +151,7 @@ volume_mount_cb (GObject *source_object,
 			primary = g_strdup_printf (_("Unable to mount %s"), name);
 			g_free (name);
 			show_error_dialog (primary,
-				           error->message,
-					   NULL);
+				           error->message);
 			g_free (primary);
 		}
 		g_error_free (error);
@@ -179,25 +175,23 @@ do_mount_volume (GVolume *volume)
 static void
 check_volume_queue (GsdAutomountManager *manager)
 {
-        GList *l, *next;
+        GList *l;
         GVolume *volume;
 
+        if (manager->priv->screensaver_active)
+                return;
+
         l = manager->priv->volume_queue;
 
-        if (manager->priv->screensaver_active) {
-                return;
-        }
-
         while (l != NULL) {
                 volume = l->data;
-                next = l->next;
 
                 do_mount_volume (volume);
                 manager->priv->volume_queue =
                         g_list_remove (manager->priv->volume_queue, volume);
 
                 g_object_unref (volume);
-                l = next;
+                l = l->next;
         }
 
         manager->priv->volume_queue = NULL;
@@ -207,9 +201,8 @@ static void
 check_screen_lock_and_mount (GsdAutomountManager *manager,
                              GVolume *volume)
 {
-        if (!manager->priv->session_is_active) {
+        if (!manager->priv->session_is_active)
                 return;
-        }
 
         if (manager->priv->screensaver_active) {
                 /* queue the volume, to mount it after the screensaver state changed */
@@ -219,7 +212,7 @@ check_screen_lock_and_mount (GsdAutomountManager *manager,
         } else {
                 /* mount it immediately */
                 do_mount_volume (volume);
-        }       
+        }
 }
 
 static void
@@ -270,11 +263,10 @@ autorun_show_window (GMount *mount, gpointer user_data)
 		name = g_mount_get_name (mount);
 		primary = g_strdup_printf (_("Unable to open a folder for %s"), name);
 		g_free (name);
-        	show_error_dialog (primary,
-        		           error->message,
-        			   NULL);
+		show_error_dialog (primary,
+				   error->message);
 		g_free (primary);
-        	g_error_free (error);
+		g_error_free (error);
         }
 
         g_free (uri);
@@ -670,13 +662,5 @@ gsd_automount_manager_init (GsdAutomountManager *manager)
 GsdAutomountManager *
 gsd_automount_manager_new (void)
 {
-        if (manager_object != NULL) {
-                g_object_ref (manager_object);
-        } else {
-                manager_object = g_object_new (GSD_TYPE_AUTOMOUNT_MANAGER, NULL);
-                g_object_add_weak_pointer (manager_object,
-                                           (gpointer *) &manager_object);
-        }
-
-        return GSD_AUTOMOUNT_MANAGER (manager_object);
+        return GSD_AUTOMOUNT_MANAGER (g_object_new (GSD_TYPE_AUTOMOUNT_MANAGER, NULL));
 }
