@@ -316,32 +316,6 @@ gsd_keyboard_manager_stop (GsdKeyboardManager *manager)
         gsd_keyboard_xkb_shutdown ();
 }
 
-static void
-gsd_keyboard_manager_set_property (GObject        *object,
-                                   guint           prop_id,
-                                   const GValue   *value,
-                                   GParamSpec     *pspec)
-{
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static void
-gsd_keyboard_manager_get_property (GObject        *object,
-                                   guint           prop_id,
-                                   GValue         *value,
-                                   GParamSpec     *pspec)
-{
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
 static GObject *
 gsd_keyboard_manager_constructor (GType                  type,
                                   guint                  n_construct_properties,
@@ -356,21 +330,12 @@ gsd_keyboard_manager_constructor (GType                  type,
         return G_OBJECT (keyboard_manager);
 }
 
-static void
-gsd_keyboard_manager_dispose (GObject *object)
-{
-        G_OBJECT_CLASS (gsd_keyboard_manager_parent_class)->dispose (object);
-}
-
 static void
 gsd_keyboard_manager_class_init (GsdKeyboardManagerClass *klass)
 {
         GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->get_property = gsd_keyboard_manager_get_property;
-        object_class->set_property = gsd_keyboard_manager_set_property;
         object_class->constructor = gsd_keyboard_manager_constructor;
-        object_class->dispose = gsd_keyboard_manager_dispose;
         object_class->finalize = gsd_keyboard_manager_finalize;
 
         g_type_class_add_private (klass, sizeof (GsdKeyboardManagerPrivate));
