@@ -101,31 +101,6 @@ G_DEFINE_TYPE (GsdMouseManager, gsd_mouse_manager, G_TYPE_OBJECT)
 
 static gpointer manager_object = NULL;
 
-static void
-gsd_mouse_manager_set_property (GObject        *object,
-                               guint           prop_id,
-                               const GValue   *value,
-                               GParamSpec     *pspec)
-{
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static void
-gsd_mouse_manager_get_property (GObject        *object,
-                               guint           prop_id,
-                               GValue         *value,
-                               GParamSpec     *pspec)
-{
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
 
 static GObject *
 gsd_mouse_manager_constructor (GType                  type,
@@ -152,8 +127,6 @@ gsd_mouse_manager_class_init (GsdMouseManagerClass *klass)
 {
         GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->get_property = gsd_mouse_manager_get_property;
-        object_class->set_property = gsd_mouse_manager_set_property;
         object_class->constructor = gsd_mouse_manager_constructor;
         object_class->dispose = gsd_mouse_manager_dispose;
         object_class->finalize = gsd_mouse_manager_finalize;
